pydecor.decorators package
==========================

Submodules
----------

.. toctree::

   pydecor.decorators.generic
   pydecor.decorators.ready_to_wear

Module contents
---------------

.. automodule:: pydecor.decorators
   :members:
   :undoc-members:
   :show-inheritance:
